@@ -5,13 +5,15 @@ use warnings;
 
 use Catalyst::Runtime '5.70';
 
-use Catalyst qw/ Static::Simple /;
+use Catalyst qw/ Static::Simple::ByClass /;
 
 our $VERSION = '0.01';
 
 __PACKAGE__->config( 
     name => 'MyRDGC',
     default_view => 'RDGC',
+    'Plugin::Static::Simple::ByClass' =>
+        { classes => [qw( CatalystX::CRUD::YUI::TT )], }
 );
 __PACKAGE__->setup;
 
