@@ -3,7 +3,7 @@
 drop table  if exists addresses;
 create table addresses
 (
-    id           serial primary key,
+    id           integer primary key autoincrement,
     name1        char(40),
     name2        char(40),
     name3        char(40),
@@ -13,7 +13,7 @@ create table addresses
 drop table  if exists suppliers;
 create table suppliers 
 (
-    id          serial primary key,
+    id          integer primary key autoincrement,
     name        char(40),
     address     integer not null,
     foreign key (address) references addresses (id)
@@ -24,7 +24,7 @@ create unique index suppliers_name on suppliers(name);
 drop table  if exists manufacturers;
 create table manufacturers
 (
-    id          serial primary key,
+    id          integer primary key autoincrement,
     name        char(40),
     address     integer not null,
     foreign key (address) references addresses (id)
@@ -35,7 +35,7 @@ create unique index manufacturers_name on manufacturers(name);
 drop table  if exists products;
 create table products
 (
-    id              serial primary key,
+    id              integer primary key autoincrement,
     manufacturer    integer not null,
     name            char(40),
     superceded      integer,
@@ -48,7 +48,7 @@ create unique index products_manufacturer_name on products(manufacturer,name);
 drop table  if exists locations;
 create table locations
 (
-    id          serial primary key,
+    id          integer primary key autoincrement,
     name        char(40),
     address     integer not null,
     foreign key (address) references addresses (id)
@@ -59,7 +59,7 @@ create unique index locations_name on locations(name);
 drop table  if exists stocks;
 create table stocks
 (
-    id          serial primary key,
+    id          integer primary key autoincrement,
     location    integer not null,    
     product     integer not null,
     quantity    integer not null,
@@ -72,7 +72,7 @@ create unique index stocks_location_product on stocks(location,product);
 drop table  if exists customers;
 create table customers
 (
-    id          integer    auto increment not null,
+    id          integer primary key autoincrement,
     name        char(40),
     address     integer not null,
     foreign key (address) references addresses (id)
@@ -83,7 +83,7 @@ create unique index customers_name on customers(name);
 drop table  if exists invoices;
 create table invoices
 (
-    id          integer auto increment not null,
+    id          integer primary key autoincrement,
     customer    integer not null,
     order_no    char(40),
     address     integer not null,
@@ -95,7 +95,7 @@ create table invoices
 drop table  if exists lines;
 create table lines
 (
-    id          serial primary key,
+    id          integer primary key autoincrement,
     invoice     integer not null,
     item        integer not null,
     stock       integer not null,
